"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

require("core-js/modules/es.array.iterator.js");

require("core-js/modules/es.promise.js");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.StartCmd = void 0;

function _defineProperty2() {
  const data = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

  _defineProperty2 = function () {
    return data;
  };

  return data;
}

function _react() {
  const data = _interopRequireDefault(require("react"));

  _react = function () {
    return data;
  };

  return data;
}

function _uiFoundationCli() {
  const data = require("@teambit/ui-foundation.cli.ui-server-console");

  _uiFoundationCli = function () {
    return data;
  };

  return data;
}

class StartCmd {
  constructor(
  /**
   * access to the extension instance.
   */
  ui, logger) {
    this.ui = ui;
    this.logger = logger;
    (0, _defineProperty2().default)(this, "name", 'start [type] [pattern]');
    (0, _defineProperty2().default)(this, "description", 'Start a dev environment for a workspace or a specific component');
    (0, _defineProperty2().default)(this, "alias", 'c');
    (0, _defineProperty2().default)(this, "group", 'development');
    (0, _defineProperty2().default)(this, "shortDescription", '');
    (0, _defineProperty2().default)(this, "options", [['d', 'dev', 'start UI server in dev mode.'], ['p', 'port [number]', 'port of the UI server.'], ['r', 'rebuild', 'rebuild the UI'], ['v', 'verbose', 'showing verbose output for inspection and prints stack trace'], ['', 'suppress-browser-launch', 'do not automatically open browser when ready']]);
  }

  async report([uiRootName, userPattern], {
    dev,
    port,
    rebuild,
    verbose
  }) {
    this.logger.off();
    const pattern = userPattern && userPattern.toString();
    const uiServer = await this.ui.createRuntime({
      uiRootName,
      pattern,
      dev,
      port: port ? parseInt(port) : undefined,
      rebuild,
      verbose
    });
    return `Bit server has started on port ${uiServer.port}`;
  }

  async render([uiRootName, userPattern], {
    dev,
    port,
    rebuild,
    verbose
  }) {
    // remove wds logs until refactoring webpack to a worker through the Worker aspect.
    // const processWrite = process.stdout.write.bind(process.stdout);
    // process.stdout.write = (data, cb) => {
    //   if (data.includes('｢wds｣') && !verbose) return processWrite('', cb);
    //   return processWrite(data, cb);
    // };
    const pattern = userPattern && userPattern.toString();
    this.logger.off();
    const ui = this.ui.getUi();
    if (!ui) throw new Error('ui not found');
    const [, uiRoot] = ui;
    const appName = uiRoot.name;
    const uiServer = this.ui.createRuntime({
      uiRootName,
      pattern,
      dev,
      port: port ? parseInt(port) : undefined,
      rebuild,
      verbose
    }); // DO NOT CHANGE THIS - this meant to be an async hook.
    // eslint-disable-next-line @typescript-eslint/no-floating-promises

    this.ui.invokeOnStart();
    this.ui.clearConsole();
    return /*#__PURE__*/_react().default.createElement(_uiFoundationCli().UIServerConsole, {
      appName: appName,
      futureUiServer: uiServer
    });
  }

}

exports.StartCmd = StartCmd;

//# sourceMappingURL=start.cmd.js.map